#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-types
version: 0.3.6
id: xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
key: xmlty_Ig8FQkC5nvD44nK4uZknsI
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-xml/
synopsis: Basic types for representing XML
category: Text, XML
author: John Millikin <jmillikin@gmail.com>
exposed: True
exposed-modules:
    Data.XML.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-types-0.3.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-types-0.3.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-types-0.3.6
hs-libraries: HSxml-types-0.3.6-Ig8FQkC5nvD44nK4uZknsI
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html: /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
